bayespy.inference.vmp.nodes.gaussian.WrapToGaussianWishart.__init__
===================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: WrapToGaussianWishart.__init__